===================================================
Neutron plugins/drivers for NEC networking products
===================================================

This repository provides Neutron plugins/drivers for NEC networking
products (mainly OpenFlow related at now) and Trema Sliceable Switch
(reference implementation).

NEC OpenFlow Neutron plugin is maintained here.

In 2015.1 release (Kilo development cycle) in OpenStack, Neutron
community decided to decompose vendor plugins/drivers from the neutron
code repo to address many pain points.

* Documentation: https://wiki.openstack.org/wiki/Neutron/NEC_OpenFlow_Plugin
* Source: http://git.openstack.org/cgit/stackforge/networking-nec
* Bugs: http://bugs.launchpad.net/networking-nec
* Free software: Apache license
